@@ -5,9 +5,7 @@
 """Helper module for gl_{track, untrack, resolve}."""
 
 
-import os
-
-import pprint
+from . import pprint
 
 from gitless.core import file as file_lib
 
@@ -20,7 +18,7 @@ def parser(help_msg, subcmd):
     p = subparsers.add_parser(
         subcmd, help=help_msg)
     p.add_argument(
-        'files', nargs='+', help='the file(s) to {}'.format(subcmd))
+        'files', nargs='+', help='the file(s) to {0}'.format(subcmd))
     p.set_defaults(func=main(subcmd))
   return f
 
@@ -32,40 +30,40 @@ def main(subcmd):
     for fp in args.files:
       ret = getattr(file_lib, subcmd)(fp)
       if ret == file_lib.FILE_NOT_FOUND:
-        pprint.err('Can\'t {} a non-existent file: {}'.format(subcmd, fp))
+        pprint.err('Can\'t {0} a non-existent file: {1}'.format(subcmd, fp))
         success = False
       elif ret == file_lib.FILE_IS_DIR:
         pprint.dir_err_exp(fp, subcmd)
         success = False
       elif ret is file_lib.FILE_ALREADY_UNTRACKED:
-        pprint.err('File {} is already untracked'.format(fp))
+        pprint.err('File {0} is already untracked'.format(fp))
         success = False
       elif ret is file_lib.FILE_ALREADY_TRACKED:
-        pprint.err('File {} is already tracked'.format(fp))
+        pprint.err('File {0} is already tracked'.format(fp))
         success = False
       elif ret is file_lib.FILE_IS_IGNORED:
-        pprint.err('File {} is ignored. Nothing to {}'.format(fp, subcmd))
+        pprint.err('File {0} is ignored. Nothing to {1}'.format(fp, subcmd))
         pprint.err_exp(
-            'edit the .gitignore file to stop ignoring file {}'.format(fp))
+            'edit the .gitignore file to stop ignoring file {0}'.format(fp))
         success = False
       elif ret is file_lib.FILE_IN_CONFLICT:
-        pprint.err('Can\'t {} a file in conflict'.format(subcmd))
+        pprint.err('Can\'t {0} a file in conflict'.format(subcmd))
         success = False
       elif ret is file_lib.FILE_NOT_IN_CONFLICT:
-        pprint.err('File {} has no conflicts'.format(fp))
+        pprint.err('File {0} has no conflicts'.format(fp))
         success = False
       elif ret is file_lib.FILE_ALREADY_RESOLVED:
         pprint.err(
-            'Nothing to resolve. File {} was already marked as resolved'.format(
-                fp))
+            'Nothing to resolve. File {0} was already marked as '
+            'resolved'.format(fp))
         success = False
       elif ret is file_lib.SUCCESS:
         pprint.msg(
-            'File {} is now a{} {}{}d file'.format(
+            'File {0} is now a{1} {2}{3}d file'.format(
                 fp, 'n' if subcmd.startswith(VOWELS) else '', subcmd,
                 '' if subcmd.endswith('e') else 'e'))
       else:
-        raise Exception('Unexpected return code {}'.format(ret))
+        raise Exception('Unexpected return code {0}'.format(ret))
 
     return success
   return f
