@@ -5,7 +5,7 @@
 """gl resolve - Mark a file with conflicts as resolved."""
 
 
-import file_cmd
+from . import file_cmd
 
 
 parser = file_cmd.parser('mark files with conflicts as resolved', 'resolve')
