@@ -5,55 +5,60 @@
 """Gitless's remote lib."""
 
 
+import collections
+
 from gitpylib import remote as git_remote
 
 
-# Ret codes of methods.
+# Ret codes of functions.
 SUCCESS = 1
 REMOTE_NOT_FOUND = 2
 REMOTE_ALREADY_SET = 3
 REMOTE_NOT_FOUND = 4
 REMOTE_UNREACHABLE = 5
+INVALID_NAME = 6
 
 
 def add(remote_name, remote_url):
-  """Add a remote for the current Gitless repo.
+  """Add a remote.
 
   Args:
     remote_name: the name of the remote.
     remote_url: the url of the remote
 
   Returns:
-    a pair (status, out) where status is one of REMOTE_ALREADY_SET,
-    REMOTE_UNREACHABLE or SUCCESS and out has additional information about the
-    remote if status=SUCCESS.
+    REMOTE_ALREADY_SET, REMOTE_UNREACHABLE or SUCCESS.
   """
+  if '/' in remote_name:
+    return INVALID_NAME
   if is_set(remote_name):
-    return (REMOTE_ALREADY_SET, None)
-  git_remote.add(remote_name, remote_url)
-  ret, out = info(remote_name)
-  if ret == REMOTE_UNREACHABLE:
-    git_remote.rm(remote_name)
-    return (REMOTE_UNREACHABLE, None)
-  return (SUCCESS, out)
-
-
-def is_set(remote_name):
-  return remote_name in git_remote.list()
+    return REMOTE_ALREADY_SET
+  s = git_remote.add(remote_name, remote_url)
+  if s == git_remote.REMOTE_UNREACHABLE:
+    return REMOTE_UNREACHABLE
+  elif s == git_remote.SUCCESS:
+    return SUCCESS
+  else:
+    raise Exception('Unrecognized ret code {0}'.format(s))
 
 
 def info(remote_name):
-  ret, info = git_remote.show(remote_name)
+  ret, remote_info = git_remote.show(remote_name)
   if ret == git_remote.REMOTE_NOT_FOUND:
     return (REMOTE_NOT_FOUND, None)
   elif ret == git_remote.REMOTE_UNREACHABLE:
     return (REMOTE_UNREACHABLE, None)
   elif ret == git_remote.SUCCESS:
-    return (SUCCESS, info)
+    return (SUCCESS, remote_info)
 
 
-def list():
-  return git_remote.list()
+RemoteInfo = collections.namedtuple(
+    'RemoteInfo', ['name', 'downstream', 'upstream'])
+
+
+def info_all():
+  for ri in git_remote.show_all_v():
+    yield RemoteInfo(ri.name, ri.fetch, ri.push)
 
 
 def rm(remote_name):
@@ -61,3 +66,7 @@ def rm(remote_name):
     return REMOTE_NOT_FOUND
   git_remote.rm(remote_name)
   return SUCCESS
+
+
+def is_set(remote_name):
+  return remote_name in git_remote.show_all()
