@@ -9,12 +9,6 @@ import os
 
 from gitpylib import common as git_common
 from gitpylib import config as git_config
-from gitpylib import repo as git_repo
-
-
-# Ret codes of methods.
-SUCCESS = 1
-NOTHING_TO_INIT = 2
 
 
 def cwd():
@@ -35,22 +29,6 @@ def gl_dir():
   return git_common.git_dir()
 
 
-def init_from(remote_repo):
-  """Clones the remote_repo into the cwd."""
-  if gl_dir():
-    return NOTHING_TO_INIT
-  git_repo.clone(remote_repo)
-  return SUCCESS
-
-
-def init_dir():
-  """Makes the cwd a Gitless's repository."""
-  if gl_dir():
-    return NOTHING_TO_INIT
-  git_repo.init()
-  return SUCCESS
-
-
 def editor():
   """Returns the editor set up by the user (defaults to Vim)."""
   ret = git_config.get('core.editor')
